##############
Citing MUSICA
##############

MUSICA can be cited in 2 ways:

1. Cite the `foundational paper <https://journals.ametsoc.org/view/journals/bams/101/10/bamsD190331.xml>`_ that defines the vision of the MUSICA software:

.. code-block:: console

    @Article { acom.software.musica-vision,
        author = "Gabriele G. Pfister and Sebastian D. Eastham and Avelino F. Arellano and Bernard Aumont and Kelley C. Barsanti and Mary C. Barth and Andrew Conley and Nicholas A. Davis and Louisa K. Emmons and Jerome D. Fast and Arlene M. Fiore and Benjamin Gaubert and Steve Goldhaber and Claire Granier and Georg A. Grell and Marc Guevara and Daven K. Henze and Alma Hodzic and Xiaohong Liu and Daniel R. Marsh and John J. Orlando and John M. C. Plane and Lorenzo M. Polvani and Karen H. Rosenlof and Allison L. Steiner and Daniel J. Jacob and Guy P. Brasseur",
        title = "The Multi-Scale Infrastructure for Chemistry and Aerosols (MUSICA)",
        journal = "Bulletin of the American Meteorological Society",
        year = "2020",
        publisher = "American Meteorological Society",
        address = "Boston MA, USA",
        volume = "101",
        number = "10",
        doi = "10.1175/BAMS-D-19-0331.1",
        pages= "E1743 - E1760",
        url = "https://journals.ametsoc.org/view/journals/bams/101/10/bamsD190331.xml"
    }

2. Cite the `MUSICA software <https://agupubs.onlinelibrary.wiley.com/doi/10.1029/2021MS002889>`_ and its evaluation (MUSICAv0):

.. code-block:: console

    @Article{acom.software.musica,
        author = {Schwantes, Rebecca H. and Lacey, Forrest G. and Tilmes, Simone and Emmons, Louisa K. and Lauritzen, Peter H. and Walters, Stacy and Callaghan, Patrick and Zarzycki, Colin M. and Barth, Mary C. and Jo, Duseong S. and Bacmeister, Julio T. and Neale, Richard B. and Vitt, Francis and Kluzek, Erik and Roozitalab, Behrooz and Hall, Samuel R. and Ullmann, Kirk and Warneke, Carsten and Peischl, Jeff and Pollack, Ilana B. and Flocke, Frank and Wolfe, Glenn M. and Hanisco, Thomas F. and Keutsch, Frank N. and Kaiser, Jennifer and Bui, Thao Paul V. and Jimenez, Jose L. and Campuzano-Jost, Pedro and Apel, Eric C. and Hornbrook, Rebecca S. and Hills, Alan J. and Yuan, Bin and Wisthaler, Armin},
        title = {Evaluating the Impact of Chemical Complexity and Horizontal Resolution on Tropospheric Ozone Over the Conterminous US With a Global Variable Resolution Chemistry Model},
        journal = {Journal of Advances in Modeling Earth Systems},
        volume = {14},
        number = {6},
        pages = {e2021MS002889},
        doi = {https://doi.org/10.1029/2021MS002889},
        url = {https://agupubs.onlinelibrary.wiley.com/doi/abs/10.1029/2021MS002889},
        eprint = {https://agupubs.onlinelibrary.wiley.com/doi/pdf/10.1029/2021MS002889},
        year = {2022}
    }